@@ -176,19 +176,16 @@ def generate_index(df, sample_cols):
     samples = sample_cols
     index_per_sample = [0] * len(samples)
     i = -1
-
+    
     ## iterate through the sampels and calculate the index given the index genes
     for sample in samples:
         i = i + 1
-        if np.mean(df[sample][df['direction'] == 'UP']) > 0:
-            if np.mean(df[sample][df['direction'] == 'DOWN']) > 0:
-                index_per_sample[i] = np.mean(df[sample][df['direction'] == 'UP']) / np.mean(df[sample][df['direction'] == 'DOWN'])
-            else:
-                pass
-        else:
-            pass
+        index_per_sample[i] = np.mean(df[sample][df['direction'] == 'UP']) / np.mean(df[sample][df['direction'] == 'DOWN'])
+        
     ## create the output dataframe by stitching this index per sample array to the corresponding sample names    
     final_df = pd.DataFrame([index_per_sample], columns = samples)
+        
+    return final_df
 
 
 ### function that takes in the index output and normalizes all values to between 0 and 1
